# Tutorial

In this tutorial we will build a small toy application from scratch.

Our application will publish random numbers to a Valkey stream, and then consume them and
update a running total. This will be enough to cover most of the features of Engin.

The final code can be found as
[an example](https://github.com/invokermain/engin/tree/main/examples/tutorial) in the Github
repo.
